/**
 * Copyright (c) Amur 2020
 * 
 * React-js-loader by Amur
 * https://github.com/AmurKhoyetsyan/react-js-loader
 * 
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */

import React, { useEffect, useState } from "react";
import Heart from "./Heart";
import Box1 from "./Box/Box1";
import Box2 from "./Box/Box2";
import Box3 from "./Box/Box3";
import Box4 from "./Box/Box4";
import Box5 from "./Box/Box5";
import Box6 from "./Box/Box6";
import Bubble1 from "./Bubble/Bubble1";
import Bubble2 from "./Bubble/Bubble2";
import Bubble3 from "./Bubble/Bubble3";
import Bubble4 from "./Bubble/Bubble4";
import Bubble5 from "./Bubble/Bubble5";
import Spinner1 from "./Spinner/Spinner1";
import Spinner2 from "./Spinner/Spinner2";
import Spinner3 from "./Spinner/Spinner3";
import Ekvalayzer from './Ekvalayzer';
import Hourglass from './Hourglass';

/**
 * @param props
 * @constructor
 */
const Loader = (props: any) => {
    const [defaultProps, setProps] = useState<any>({
        type: "spinner-default",
        bgColor: "#FFFFFF"
    });
      
    useEffect(() => {
        if(Object.keys(props).length === 0) {
            props = defaultProps;
        }
    
        let newProps = {...props};

        if(!newProps.hasOwnProperty("type")) {
            newProps.type = defaultProps.type;
        }
    
        if(!newProps.hasOwnProperty("bgColor")) {
            newProps.bgColor = defaultProps.bgColor;
        }

        setProps(newProps);
    }, [props]);

    switch(defaultProps.type) {
        case "box-rotate-x": return <Box1 {...defaultProps} />;
        case "box-rotate-y": return <Box2 {...defaultProps} />;
        case "box-rotate-z": return <Box3 {...defaultProps} /> ;
        case "box-rectangular": return <Box4 {...defaultProps} /> ;
        case "rectangular-ping": return <Box5 {...defaultProps} /> ;
        case "box-up": return <Box6 {...defaultProps} /> ;
        case "heart": return <Heart {...defaultProps} />;
        case "bubble-scale": return <Bubble1 {...defaultProps} /> ;
        case "bubble-top": return <Bubble2 {...defaultProps} /> ;
        case "bubble-ping": return <Bubble3 {...defaultProps} /> ;
        case "bubble-spin": return <Bubble4 {...defaultProps} /> ;
        case "bubble-loop": return <Bubble5 {...defaultProps} /> ;
        case "spinner-cub": return <Spinner1 {...defaultProps} /> ;
        case "spinner-circle": return <Spinner2 {...defaultProps} /> ;
        case "spinner-default": return <Spinner3 {...defaultProps} /> ;
        case "ekvalayzer": return <Ekvalayzer {...defaultProps} /> ;
        case "hourglass": return <Hourglass {...defaultProps} /> ;
        default: return <Spinner3 {...defaultProps} /> ;
    }
}

export default Loader;